#!/usr/bin/python

# Furnishing: Advanced Python OpenGL Demo
# (c) Ruediger Busch
# contact: ruediger.busch@web.de

# Initiate the OpenGL paramters

import sys
from os import path
from OpenGL.GL import *
from OpenGL.GLE import *
from OpenGL.GLU import *
from OpenGL.GLUT import *
from pyWorld import VirtualWorld

'''InitGL includes all parameters needed for inital OpenGL setup.''' 
class InitGL:
  '''Initialise an OpenGL windows with the origin at x, y and size of height, width.'''
  def __init__(self, x, y, height, width):
    glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGBA | GLUT_DEPTH)
    glutInitWindowSize(height, width)
    glutInitWindowPosition(x,y)
    glutCreateWindow("OpenGL home decoration")
    glClearDepth(1.0)
    glEnable(GL_DEPTH_TEST)
    glClearColor(0.0, 0.0, 0.0, 0.0)
    glShadeModel(GL_SMOOTH)
    glMatrixMode(GL_MODELVIEW)
    # initialize lighting */
    glLightfv(GL_LIGHT0, GL_DIFFUSE, (1,1,1,1))
    glLightfv(GL_LIGHT0, GL_AMBIENT, (0.2, 0.2, 0.2, 1))
    glLightfv(GL_LIGHT0, GL_POSITION,(0,10,1,0))
    glEnable(GL_LIGHT0)
    #glLightfv(GL_LIGHT1, GL_DIFFUSE, (0.1, 0.1, 0.1, 0.1))
    #glLightfv(GL_LIGHT1, GL_SPOT_CUTOFF, 30)
    #glLightfv(GL_LIGHT1, GL_SPOT_DIRECTION, (1,0,0))
    #glLightfv(GL_LIGHT1, GL_SPOT_EXPONENT, 1)
    #glLightfv(GL_LIGHT1, GL_SPECULAR, (1,1,1,1))
    #glEnable(GL_LIGHT1)
    # 
    #glColorMaterial(GL_FRONT, GL_DIFFUSE)
    #glEnable(GL_COLOR_MATERIAL)
    #glEnable(GL_LIGHTING)
    # Automatic vector normalise
    #glEnable(GL_NORMALIZE)
    # ### Instantiate the virtual world ###
    if len(sys.argv) > 1:
      if sys.argv[1] == '-h':
        print "usage: init.py <roomStructurFile.xml>"
	print "navigate with q, w, e, a, s, d, y, x and mouse + middle button"
	print "open menu with right mouse button"
	print "select or set selected item with left mouse button"
	print "Z and z zoom in and out"
	print "r reset zoom"
	print "f toggles screen"
	print "i toggles status bar"
	print "Esc exits"
	pyWorld = VirtualWorld(".","rooms.xml")
      else:
        filename = path.split(sys.argv[1])
        directory = filename[0]
        file = filename[1]
        if directory == '':
          directory = '.'
        pyWorld = VirtualWorld(directory, file)
    else:
      print "usage: init.py <roomStructurFile.xml>\ndefault: ./rooms.xml"
      pyWorld = VirtualWorld(".","rooms.xml")
    # #########################
    # setup the callbacks
    glutDisplayFunc(pyWorld.drawScene)
    glutMotionFunc(pyWorld.activeMouse)
    #glutPassiveMotionFunc(pyWorld.passiveMouse)
    glutMouseFunc(pyWorld.completeMouse)
    glutReshapeFunc(pyWorld.resizeScene)
    #glutMouseFunc(pyWorld.completeMouse)
    # When we are doing nothing, redraw the scene.
    glutIdleFunc(pyWorld.drawIdleScene)
    # Register the function called when the keyboard is pressed and released.
    glutIgnoreKeyRepeat(1)
    glutKeyboardFunc(pyWorld.keyPressed)
    glutKeyboardUpFunc(pyWorld.keyReleased)
    
if __name__ == '__main__':
  # initialize GLUT 
  glutInit(sys.argv)
  # Call init: Parameter(Window Position -> x, y, height, width)
  testbench=InitGL(300,150,1024,600)
  # Start Event Processing Engine	
  glutMainLoop()
